OC.L10N.register(
    "news",
    {
    "Saved" : "Đã lưu",
    "Download" : "Tải về",
    "Close" : "Đóng",
    "Language" : "Ngôn ngữ",
    "Subscribe" : "Theo dõi",
    "by" : "bởi",
    "from" : "từ",
    "Description" : "Mô tả",
    "right" : "phải",
    "left" : "trái",
    "Refresh" : "Làm mới",
    "Web address" : "Địa chỉ Web",
    "Feed exists already!" : "Nguồn đã tồn tại",
    "Folder" : "Thư mục",
    "No folder" : "Không có thư mục nào",
    "New folder" : "Tạo thư mục",
    "Folder name" : "Tên thư mục",
    "Go back" : "Quay lại",
    "Folder exists already!" : "Thư mục đã tồn tại!",
    "Credentials" : "Giấy chứng nhận",
    "Username" : "Tên đăng nhập",
    "Password" : "Mật khẩu",
    "Create" : "Tạo",
    "Rename" : "Sửa tên",
    "Newest first" : "Mới trước",
    "Oldest first" : "Cũ trước",
    "Delete" : "Xóa",
    "Dismiss" : "Bỏ qua",
    "Collapse" : "Thu gọn",
    "Starred" : "Starred",
    "Unread articles" : "Bài chưa đọc",
    "All articles" : "Mọi bài viết",
    "Settings" : "Cài đặt",
    "Import" : "Nhập vào",
    "Export" : "Xuất ra",
    "Help" : "Giúp đỡ",
    "Keyboard shortcuts" : "Phím tắt",
    "Documentation" : "Tài liệu hướng dẫn",
    "Report a bug" : "Báo cáo lỗi"
},
"nplurals=1; plural=0;");
